@@ -1,6 +1,9 @@
 package Array::Find;
 
-use 5.010;
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.08'; # VERSION
+
+use 5.010001;
 use strict;
 use warnings;
 
@@ -10,11 +13,10 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(find_in_array);
 
-our $VERSION = '0.07'; # VERSION
-
 our %SPEC;
 
 $SPEC{find_in_array} = {
+    v => 1.1,
     summary       => 'Find items in array, with several options',
     description   => <<'_',
 
@@ -29,7 +31,7 @@ work with scalars and compare things asciibetically.
 
 _
     args          => {
-        item             => ['str' => {
+        item             => {
             summary      => 'Item to find',
             description  => <<'_',
 
@@ -37,9 +39,10 @@ Currently can only be scalar. See also 'items' if you want to find several items
 at once.
 
 _
-            arg_pos      => 0,
-        }],
-        array            => ['array' => {
+            schema       => ['str*'],
+            pos          => 0,
+        },
+        array            => {
             summary      => 'Array to find items in',
             description  => <<'_',
 
@@ -47,10 +50,10 @@ See also 'arrays' if you want to find in several arrays. Array elements can be
 undef and will only match undef.
 
 _
-            arg_pos      => 1,
-        }],
-        items            => ['array' => {
-            of           => 'str',
+            schema       => ['array*' => of=>'str*'],
+            pos          => 1,
+        },
+        items            => {
             summary      => "Just like 'item', except several",
             description  => <<'_',
 
@@ -61,9 +64,9 @@ Example: find_in_array(items => ["a", "b"], array => ["b", "a", "c", "a"]) will
 return result ["b", "a", "a"].
 
 _
-        }],
-        arrays            => ['array' => {
-            of           => 'array', # XXX ['array*'=>{of=>'str'}]
+            schema       => ['array*' => of => 'str*'],
+        },
+        arrays            => {
             summary      => "Just like 'array', except several",
             description  => <<'_',
 
@@ -73,8 +76,9 @@ Example: find_in_array(item => "a", arrays => [["b", "a"], ["c", "a"]]) will
 return result ["a", "a"].
 
 _
-        }],
-        max_result       => ['int' => {
+            schema       => ['array*' => of=>['array*', of=>'str*']],
+        },
+        max_result       => {
             summary      => "Set maximum number of results",
             description  => <<'_',
 
@@ -90,8 +94,9 @@ array=>['a', 'b', 'a', 'a'], max_result=>2) will return result ['a', 'a'].
  found it will stop.
 
 _
-        }],
-        max_compare      => ['int' => {
+            schema       => ['int*', min=>1],
+        },
+        max_compare      => {
             summary      => "Set maximum number of comparison",
             description  => <<'_',
 
@@ -101,17 +106,14 @@ find(item=>'a', array=>['q', 'w', 'e', 'a'], max_compare=>3) will not return
 result.
 
 _
-        }],
-        ci               => ['bool' => {
-            default      => 0,
+            schema       => ['int*' => min=>1],
+        },
+        ci               => {
             summary      => "Set case insensitive",
-        }],
-        mode             => ['str' => {
-            in           => ['exact', 'prefix', 'suffix', 'infix',
-                             'prefix|infix', 'prefix|suffix',
-                             'prefix|infix|suffix', 'infix|suffix',
-                             'regex'],
-            default      => 'exact',
+            schema       => 'bool',
+            default      => 0,
+        },
+        mode             => {
             summary      => "Comparison mode",
             description  => <<'_',
 
@@ -123,12 +125,16 @@ match on each element of array.
 
 See also 'word_sep' which affects prefix/suffix/infix matching.
 _
-        }],
-        word_sep         => ['str' => {
+            schema       => ['str' => in => [
+                'exact', 'prefix', 'suffix', 'infix',
+                'prefix|infix', 'prefix|suffix',
+                'prefix|infix|suffix', 'infix|suffix',
+                'regex',
+            ]],
+            default      => 'exact',
+        },
+        word_sep         => {
             summary      => "Define word separator",
-            arg_aliases  => {
-                ws => {},
-            },
             description  => <<'_',
 
 If set, item and array element will be regarded as a separated words. This will
@@ -139,19 +145,24 @@ not 'ca.b'). Infix matching will match 'c.a.b.c' and won't match 'a.b',
 'a.b.c', or 'c.a.b'.
 
 _
-        }],
-        unique           => ['bool' => {
+            schema       => 'str*',
+            cmdline_aliases  => {ws => {}},
+        },
+        unique           => {
             summary      => "Whether to return only unique results",
-            arg_aliases  => {
-                u => {},
-            },
+            schema       => ['bool'],
+            cmdline_aliases  => { u => {} },
             description  => <<'_',
 If set to true, results will not contain duplicate items.
 _
-        }],
-        shuffle          => ['bool' => {
+        },
+        shuffle          => {
             summary      => "Shuffle result",
-        }],
+            schema       => 'bool',
+        },
+    },
+    args_rels => {
+        'req_one&' => [['item', 'items'], ['array', 'arrays']],
     },
     result_naked => 1,
 };
@@ -324,18 +335,19 @@ sub find_in_array {
 1;
 # ABSTRACT: Find items in array, with several options
 
-
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Array::Find - Find items in array, with several options
 
 =head1 VERSION
 
-version 0.07
+This document describes version 0.08 of Array::Find (from Perl distribution Array-Find), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -371,31 +383,14 @@ version 0.07
 
 This module provides one subroutine: C<find_in_array> to find items in array.
 
-This module has L<Rinci> metadata.
-
 =head1 FUNCTIONS
 
-None of the functions are exported by default, but they are exportable.
-
-=head1 SEE ALSO
-
-L<List::Util>, L<List::MoreUtils>
-
-=head1 DESCRIPTION
-
-
-This module has L<Rinci> metadata.
-
-=head1 FUNCTIONS
-
-
-None are exported by default, but they are exportable.
 
 =head2 find_in_array(%args) -> any
 
 Find items in array, with several options.
 
-findI<in>array looks for one or more items in one or more arrays and return an
+find_in_array looks for one or more items in one or more arrays and return an
 array containing all or some results (empty arrayref if no results found). You
 can specify several options, like maximum number of results, maximum number of
 comparisons, searching by suffix/prefix, case sensitivity, etc. Consult the list
@@ -408,20 +403,20 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<array> => I<array>
+=item * B<array> => I<array[str]>
 
 Array to find items in.
 
 See also 'arrays' if you want to find in several arrays. Array elements can be
 undef and will only match undef.
 
-=item * B<arrays> => I<array>
+=item * B<arrays> => I<array[array[str]]>
 
 Just like 'array', except several.
 
 Use this to find several items at once.
 
-Example: findI<in>array(item => "a", arrays => [["b", "a"], ["c", "a"]]) will
+Example: find_in_array(item => "a", arrays => [["b", "a"], ["c", "a"]]) will
 return result ["a", "a"].
 
 =item * B<ci> => I<bool> (default: 0)
@@ -435,14 +430,14 @@ Item to find.
 Currently can only be scalar. See also 'items' if you want to find several items
 at once.
 
-=item * B<items> => I<array>
+=item * B<items> => I<array[str]>
 
 Just like 'item', except several.
 
 Use this to find several items at once. Elements can be undef if you want to
 search for undef.
 
-Example: findI<in>array(items => ["a", "b"], array => ["b", "a", "c", "a"]) will
+Example: find_in_array(items => ["a", "b"], array => ["b", "a", "c", "a"]) will
 return result ["b", "a", "a"].
 
 =item * B<max_compare> => I<int>
@@ -450,8 +445,8 @@ return result ["b", "a", "a"].
 Set maximum number of comparison.
 
 Maximum number of elements in array(s) to look for, 0 means unlimited. Finding
-will stop as soon as this limit is reached, regardless of maxI<result. Example:
-find(item=>'a', array=>['q', 'w', 'e', 'a'], max>compare=>3) will not return
+will stop as soon as this limit is reached, regardless of max_result. Example:
+find(item=>'a', array=>['q', 'w', 'e', 'a'], max_compare=>3) will not return
 result.
 
 =item * B<max_result> => I<int>
@@ -460,12 +455,12 @@ Set maximum number of results.
 
 0 means unlimited (find in all elements of all arrays).
 
-+N means find until results have N items. Example: findI<in>array(item=>'a',
++N means find until results have N items. Example: find_in_array(item=>'a',
 array=>['a', 'b', 'a', 'a'], max_result=>2) will return result ['a', 'a'].
 
 -N is useful when looking for multiple items (see 'items' argument). It means
  find until N items to look for have been found. Example:
- findI<in>array(items=>['a','b'], array=>['a', 'a', 'b', 'b'], max_results=>-2)
+ find_in_array(items=>['a','b'], array=>['a', 'a', 'b', 'b'], max_results=>-2)
  will return result ['a', 'a', 'b']. As soon as 2 items to look for have been
  found it will stop.
 
@@ -504,18 +499,37 @@ not 'ca.b'). Infix matching will match 'c.a.b.c' and won't match 'a.b',
 
 =back
 
-Return value:
+Return value:  (any)
+
+=head1 SEE ALSO
+
+L<List::Util>, L<List::MoreUtils>
+
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Array-Find>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Array-Find>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Array-Find>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
